@@ -19,6 +19,6 @@ class DoNotDetect(UnmarkedMissingValueDetectionStrategy):
         ts: DataFrame,
         time_col_name: str,
         data_col_name: str,
-        regularity_report: AnalysisReport,
+        period: int
     ) -> DataFrame:
         return ts
